/***************************************************************************
 *   Copyright (C) 2007 by    *
 *      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#include "laserinterlock.h"
#include <qtango.h>

laserinterlock::laserinterlock(QWidget *parent) : QWidget(parent)
{
	QSettings settings("fermi", "acs");
	// load (or set) path for images
	if (settings.contains("imgpath")) {
		imgpath = settings.value("imgpath").toString();
		// cout << imgpath.toStdString() << endl;
	}
	else {
		settings.setValue("imgpath", "/runtime/fermi/share/images/acs");
		// settings.setValue("imgpath", "/home/zambonl/devel/qt/fermi/acs/img");
	}
	if (!imgpath.endsWith("/")) {
		imgpath = imgpath + "/";
	}
	// setup User Interface
	ui.setupUi(this);

	ui.shutter_stat_lh->setEnumDisplay(0, 0, QString("MOVING"), QColor(120, 120, 255));
	ui.shutter_stat_lh->setEnumDisplay(0, 1, QString("CLOSED"), QColor(240, 240, 0));
	ui.shutter_stat_lh->setEnumDisplay(0, 2, QString("OPEN"), QColor(93, 234, 78));
	ui.shutter_stat_lh->setEnumDisplay(0, 3, QString("FAULT"), QColor(220, 0, 0));

	ui.attenuator_stat_lh->setEnumDisplay(0, 0, QString("MOVING"), QColor(120, 120, 255));
	ui.attenuator_stat_lh->setEnumDisplay(0, 1, QString("INSERTED"), QColor(250, 250, 0));
	ui.attenuator_stat_lh->setEnumDisplay(0, 2, QString("REMOVED"), QColor(93, 234, 78));
	ui.attenuator_stat_lh->setEnumDisplay(0, 3, QString("FAULT"), QColor(220, 0, 0));

	ui.attenuator_stat_fel1->setEnumDisplay(0, 0, QString("MOVING"), QColor(255, 255, 255));
	ui.attenuator_stat_fel1->setEnumDisplay(0, 1, QString("INSERTED"), QColor(250, 250, 0));
	ui.attenuator_stat_fel1->setEnumDisplay(0, 2, QString("REMOVED"), QColor(93, 234, 78));
	ui.attenuator_stat_fel1->setEnumDisplay(0, 3, QString("FAULT"), QColor(220, 0, 0));

	ui.attenuator_stat_fel1_2->setEnumDisplay(0, 0, QString("MOVING"), QColor(255, 255, 255));
	ui.attenuator_stat_fel1_2->setEnumDisplay(0, 1, QString("INSERTED"), QColor(250, 250, 0));
	ui.attenuator_stat_fel1_2->setEnumDisplay(0, 2, QString("REMOVED"), QColor(93, 234, 78));
	ui.attenuator_stat_fel1_2->setEnumDisplay(0, 3, QString("FAULT"), QColor(220, 0, 0));


	ui.attenuator_stat_fel2->setEnumDisplay(0, 0, QString("MOVING"), QColor(120, 120, 255));
	ui.attenuator_stat_fel2->setEnumDisplay(0, 1, QString("INSERTED"), QColor(250, 250, 0));
	ui.attenuator_stat_fel2->setEnumDisplay(0, 2, QString("REMOVED"), QColor(93, 234, 78));
	ui.attenuator_stat_fel2->setEnumDisplay(0, 3, QString("FAULT"), QColor(220, 0, 0));

	ui.InfoButton_lh->setIcon(QPixmap(imgpath+"/info.png"));
	ui.InfoButton_fel1->setIcon(QPixmap(imgpath+"/info.png"));
	ui.InfoButton_fel1_2->setIcon(QPixmap(imgpath+"/info.png"));
	ui.InfoButton_fel2->setIcon(QPixmap(imgpath+"/info.png"));
	connect(ui.InfoButton_lh, SIGNAL(clicked()), this, SLOT(open_laserscreens()));
	laserscreens_process = new QProcess(this);
	connect(ui.InfoButton_fel1, SIGNAL(clicked()), this, SLOT(open_fel1screens()));
	connect(ui.InfoButton_fel1_2, SIGNAL(clicked()), this, SLOT(open_fel1screens()));
	fel1screens_process = new QProcess(this);
	connect(ui.InfoButton_fel2, SIGNAL(clicked()), this, SLOT(open_fel2screens()));
	fel2screens_process = new QProcess(this);
	
}

laserinterlock::~laserinterlock()
{
	exit(0);
}    


void laserinterlock::open_laserscreens()
{
	if (laserscreens_process->state() == QProcess::Running) {
		laserscreens_process->kill();
		laserscreens_process->waitForFinished(3000);			
	}	
	laserscreens_process->start("laserscreens");
}

void laserinterlock::open_fel1screens()
{
	if (fel1screens_process->state() == QProcess::Running) {
		fel1screens_process->kill();
		fel1screens_process->waitForFinished(3000);			
	}	
	fel1screens_process->start("fel1screens");
}

void laserinterlock::open_fel2screens()
{
	if (fel2screens_process->state() == QProcess::Running) {
		fel2screens_process->kill();
		fel2screens_process->waitForFinished(3000);			
	}	
	fel2screens_process->start("fel2screens");
}
